<?php
/**
 *
 * Random Banner Scroll. An extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2017, Galandas, http://phpbb3world.altervista.org
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace galandas\bannerscroll\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{
	protected $db;
	protected $user;
	protected $config;
	protected $template;
	protected $helper;	
	protected $table;

	public function __construct(\phpbb\db\driver\driver_interface $db, \phpbb\user $user, \phpbb\config\config $config, \phpbb\template\template $template, \phpbb\controller\helper $helper, $banner, \phpbb\collapsiblecategories\operator\operator $operator = null)		
		
	{
		$this->db = $db;
		$this->config = $config;
		$this->template = $template;
		$this->helper = $helper;		
		$this->table = $banner;
		$this->operator = $operator;		
	}


	static public function getSubscribedEvents ()
	{
		return array(
			'core.permissions'	=> 'add_permission',		
			'core.user_setup'	=> 'load_language_on_setup',		
			'core.page_header'	=> 'display_banner_scroll',
		);
	}
	
	/**
	* Add permissions acp Random Banner Scroll
	*/
	public function add_permission($event)
	{
		$permissions = $event['permissions'];
		$permissions['a_rbs'] = array('lang' => 'ACL_A_BANNER', 'cat' => 'misc');
		$event['permissions'] = $permissions;
	}	

	/**
	* Display Random Banner Scroll Extension by Galandas
	*
	* @return null
	* @access public
	*/
	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'galandas/bannerscroll',
			'lang_set' => 'common',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}
	
	public function display_banner_scroll($event)
	{
	    // Maneggiare Random Diversamente		
			$sql_layer = $this->db->get_sql_layer();
			switch ($sql_layer)
			{
				case 'postgres':
					$random = 'RANDOM()';
				break;

				case 'mssql':
				case 'mssql_odbc':
					$random = 'NEWID()';
				break;

				default:
					$random = 'RAND()';
				break;
			}
	
        $sql = "SELECT * FROM " . $this->table . "
        ORDER BY $random";
        $result_banner = $this->db->sql_query_limit($sql, 15);
        while( $row_banner = $this->db->sql_fetchrow($result_banner) ) 
    {
        $this->template->assign_block_vars('banner_scroll', array(
        'B_NAME'		=> $row_banner['banner_name'],		
        'B_IMG'			=> $row_banner['banner_image'],
        'B_URL'			=> $row_banner['banner_url'],
        ));
    }
    $this->db->sql_freeresult($result_banner);	
	
		if ($this->operator !== null)
		{
			$fid = 'banner'; // Può essere qualsiasi stringa univoca per identificare l'elemento pieghevole delle estensioni
			$this->template->assign_vars(array(
				'BANNER_IS_COLLAPSIBLE'	=> true,
				'S_BANNER_HIDDEN' => in_array($fid, $this->operator->get_user_categories()),
				'U_BANNER_COLLAPSE_URL' => $this->helper->route('phpbb_collapsiblecategories_main_controller', array('forum_id' => $fid, 
				'hash' => generate_link_hash("collapsible_$fid")))
			));			
		}
	$this->template->assign_vars(array(
		'S_BANNER_SCROLL_ENABLED' 	     	=> (!empty($this->config['banner_scroll_enable'])) ? true : false,
    ));		
	}	
}